--[[
	TitanConquestWeekly: A simple display of your current Conquest value.
	Author: InvisiBill
--]]

local ADDON_NAME, L = ...;
local VERSION = GetAddOnMetadata(ADDON_NAME, "Version")

local CurrencyID = 1602;  --Conquest
local QuestLineID = 782;  --Conquest Weekly Questline
local MaxLvl = MAX_PLAYER_LEVEL_TABLE[#MAX_PLAYER_LEVEL_TABLE]
local name, _, texturePath, _, _, _, _, _ = GetCurrencyInfo(CurrencyID)

-----------------------------------------------
local function GetButtonText(self, id)
    local name = name .. ": "
    local text = "Updating..."
    if UnitLevel("player") >= MaxLvl then
        local CurrentQuestID = QuestUtils_GetCurrentQuestLineQuest(QuestLineID)
        if CurrentQuestID == 0 then
            text = "|cFF69FF69".."Done!".."|r"
        else
            local questText, _, finished, amount, weeklyMax = GetQuestObjectiveInfo(CurrentQuestID, 1, false)
            if questText then
                if amount >= 0 and amount < 0.7*weeklyMax then
                    text = "|cFF69FF69"..amount.."|r"
                elseif amount >= 0.7*weeklyMax and amount < 0.8*weeklyMax then
                    text = "|cFFf6ed12"..amount.."|r"
                elseif amount >= 0.8*weeklyMax and amount < 0.9*weeklyMax then
                    text = "|cFFf69112"..amount.."|r"
                elseif amount >= 0.9*weeklyMax and amount < weeklyMax then
                    text = "|cFFFF2e2e"..amount.."|r"
                elseif amount >= weeklyMax then
                    text = "|cFFFF0000"..amount.."|r  |T1001978:18|t"
                else
                    text = "|cFFFFFFFF"..string.format("%.0f", amount).."|r"
                end
            end
        end
    else
        text = "|cFFFF0000".."Locked".."|r"
    end
	return name, text
end

-----------------------------------------------
local function CustomTooltip()
    GameTooltip:SetCurrencyByID(CurrencyID)
end

-----------------------------------------------
local eventsTable = {
	PLAYER_ENTERING_WORLD = function(self)
		self:UnregisterEvent("PLAYER_ENTERING_WORLD")

		TitanPanelButton_UpdateButton(self.registry.id)
	end,
	CURRENCY_DISPLAY_UPDATE = function(self)
		TitanPanelButton_UpdateButton(self.registry.id)
	end,
	QUEST_LOG_UPDATE = function(self)
		TitanPanelButton_UpdateButton(self.registry.id)
	end
}

-----------------------------------------------
local function OnUpdate(self, button)
    GetButtonText()
end

-----------------------------------------------
local function OnClick(self, button)
	if (button == "LeftButton") then
        TitanPanelButton_UpdateButton(self.registry.id)
        TogglePVPUI();
	end
end

-----------------------------------------------
local menus = {
	{ type = "space" },
	{ type = "rightSideToggle" }
}

-----------------------------------------------
L.Elib({
	id = "TITAN_CONQUEST_WEEKLY",
	name = "Conquest Weekly",
	icon = texturePath,
	category = "Information",
	version = VERSION,
	getButtonText = GetButtonText,
	customTooltip = CustomTooltip,
	eventsTable = eventsTable,
	--onUpdate = OnUpdate,
	menus = menus,
	onClick = OnClick
})


